Learn R Programming

expertsurv (version 1.4.1)

elicit_surv: Elicit survival judgements interactively and estimate survival models

Description

Opens up a web browser (using the shiny package), from which you can specify judgements and fit distributions for multiple timepoints and experts. Plots of the fitted density functions are provided overlayed on the survival data (where appropriate).

Usage

elicit_surv(compile_mods = NULL)

Value

If "Download R objects" selected an expertsurv object containing the results of the elicitation and analysis. The object includes:

  • model: The fitted survival models.

  • parameters: The estimated parameters for each model.

If "Download report" selected either .html, .pdf or .docx document is downloaded with:

  • plot: Plots of the fitted survival overlayed on the Kaplan Meier data and plot of expert opinion as probability distributions.

  • summary: A summary report of the analysis including goodness of fit and parameter values.

Arguments

compile_mods

list of compiled stan models generated by compile_stan. Supplying the compiled stan models will greatly speed up the computation of the Bayesian analysis (otherwise each time a stan model is run it will be compiled (and not reused between runs)).

Author

Philip Cooney phcooney@tcd.ie

Details

Once the elicitation is complete the analysis can be run. Click "Download R objects" to download the expertsurv object generated from the analysis. Click "Download report" to generate a report including plots and parameter values for the parametric survival models. For detailed instructions use browseVignettes("expertsurv")

Examples

Run this code
if (interactive()) {
elicit_surv()
}

Run the code above in your browser using DataLab